yt.visualization.volume_rendering.transfer_functions.PlanckTransferFunction — The yt Project 3.2-dev documentation

# yt.visualization.volume_rendering.transfer_functions.PlanckTransferFunction

class `yt.visualization.volume_rendering.transfer_functions.` `PlanckTransferFunction`(T_bounds, rho_bounds, nbins=256, red='R', green='V', blue='B', anorm=1000000.0)

  This sets up a planck function for multivariate emission and absorption. We assume that the emission is black body, which is then convolved with appropriate Johnson filters for red, green and blue. T_bounds and rho_bounds define the limits of tabulated emission and absorption functions. anorm is a “fudge factor” that defines the somewhat arbitrary normalization to the scattering approximation: because everything is done largely unit-free, and is really not terribly accurate anyway, feel free to adjust this to change the relative amount of reddenning. Maybe in some future version this will be unitful.

  Methods